==> huaweicloudsdkworkspaceapp-3.1.142-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/list_future_executions_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListFutureExecutionsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'future_executions': 'list[str]',
        'time_zone': 'str'
    }

    attribute_map = {
        'future_executions': 'future_executions',
        'time_zone': 'time_zone'
    }

    def __init__(self, future_executions=None, time_zone=None):
        """ListFutureExecutionsResponse

        The model defined in huaweicloud sdk

        :param future_executions: 未来执行的具体时间列表。
        :type future_executions: list[str]
        :param time_zone: 时区
        :type time_zone: str
        """
        
        super(ListFutureExecutionsResponse, self).__init__()

        self._future_executions = None
        self._time_zone = None
        self.discriminator = None

        if future_executions is not None:
            self.future_executions = future_executions
        if time_zone is not None:
            self.time_zone = time_zone

    @property
    def future_executions(self):
        """Gets the future_executions of this ListFutureExecutionsResponse.

        未来执行的具体时间列表。

        :return: The future_executions of this ListFutureExecutionsResponse.
        :rtype: list[str]
        """
        return self._future_executions

    @future_executions.setter
    def future_executions(self, future_executions):
        """Sets the future_executions of this ListFutureExecutionsResponse.

        未来执行的具体时间列表。

        :param future_executions: The future_executions of this ListFutureExecutionsResponse.
        :type future_executions: list[str]
        """
        self._future_executions = future_executions

    @property
    def time_zone(self):
        """Gets the time_zone of this ListFutureExecutionsResponse.

        时区

        :return: The time_zone of this ListFutureExecutionsResponse.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this ListFutureExecutionsResponse.

        时区

        :param time_zone: The time_zone of this ListFutureExecutionsResponse.
        :type time_zone: str
        """
        self._time_zone = time_zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListFutureExecutionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.145-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/list_future_executions_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListFutureExecutionsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'future_executions': 'list[str]',
        'time_zone': 'str'
    }

    attribute_map = {
        'future_executions': 'future_executions',
        'time_zone': 'time_zone'
    }

    def __init__(self, future_executions=None, time_zone=None):
        r"""ListFutureExecutionsResponse

        The model defined in huaweicloud sdk

        :param future_executions: 未来执行的具体时间列表。
        :type future_executions: list[str]
        :param time_zone: 时区
        :type time_zone: str
        """
        
        super(ListFutureExecutionsResponse, self).__init__()

        self._future_executions = None
        self._time_zone = None
        self.discriminator = None

        if future_executions is not None:
            self.future_executions = future_executions
        if time_zone is not None:
            self.time_zone = time_zone

    @property
    def future_executions(self):
        r"""Gets the future_executions of this ListFutureExecutionsResponse.

        未来执行的具体时间列表。

        :return: The future_executions of this ListFutureExecutionsResponse.
        :rtype: list[str]
        """
        return self._future_executions

    @future_executions.setter
    def future_executions(self, future_executions):
        r"""Sets the future_executions of this ListFutureExecutionsResponse.

        未来执行的具体时间列表。

        :param future_executions: The future_executions of this ListFutureExecutionsResponse.
        :type future_executions: list[str]
        """
        self._future_executions = future_executions

    @property
    def time_zone(self):
        r"""Gets the time_zone of this ListFutureExecutionsResponse.

        时区

        :return: The time_zone of this ListFutureExecutionsResponse.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        r"""Sets the time_zone of this ListFutureExecutionsResponse.

        时区

        :param time_zone: The time_zone of this ListFutureExecutionsResponse.
        :type time_zone: str
        """
        self._time_zone = time_zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListFutureExecutionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
